@@ -30,16 +30,40 @@ our @EXPORT_OK = qw (
 
 ## Version of Unicode::Peek module
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 ## Load necessary modules
-
 use utf8;
+use Carp;
+use feature 'say';
 use Encode qw(decode encode);
 
 binmode( STDOUT, ':utf8' ); # debuggin purposes
 
+use constant TRUE             => 1;
+use constant FALSE            => 0;
+
+my @unicodes = ( 'UCS-2',
+		 'UCS-2BE',
+		 'UCS-2LE',
+		 'UCS-4',
+		 'UTF-7',
+		 'utf8',
+		 'utf-8-strict',
+		 'UTF-8',
+		 'UTF-16',
+		 'UTF-16BE',
+		 'UTF-16LE',
+		 'UTF-32',
+		 'UTF-32BE',
+		 'UTF-32LE' );
+
+sub _checkUnicode {
+    croak "Unknown encoding format '$_[0]'"
+	unless (grep { /$_[0]/ } @unicodes);
+}
+
 sub _ascii2hex {
     return unpack("H*", $_[0]);
 }
@@ -49,6 +73,7 @@ sub _hex2ascii {
 }
 
 sub hexDumperOutput {
+    _checkUnicode($_[0]);
     my ( $unicodeFormat , $data ) = @_;
     my $hexString = ascii2hexEncode( $unicodeFormat , $data );
     # trim leading and trailing white space
@@ -63,18 +88,21 @@ sub hexDumperOutput {
 }
 
 sub hexDumperInput {
+    _checkUnicode($_[0]);
     my ( $unicodeFormat , $arrayRef ) = @_;
     my $hexString = join('', split(/ /, join('', @$arrayRef)));
     return hex2ascciiDecode($unicodeFormat, $hexString);
 }
 
 sub ascii2hexEncode {
+    _checkUnicode($_[0]);
     my ( $unicodeFormat , $data ) = @_;
     my $octets = encode( $unicodeFormat , $data );
     return _ascii2hex( $octets );
 }
 
 sub hex2ascciiDecode {
+    _checkUnicode($_[0]);
     my ( $unicodeFormat , $data ) = @_;
     my $hex2ascciiString = _hex2ascii( $data );
     return decode( $unicodeFormat , $hex2ascciiString );
@@ -92,7 +120,7 @@ __END__
 
 =head1 VERSION
 
-    Version 0.03
+    Version 0.04
 
 
 =head1 SYNOPSIS
@@ -387,6 +415,6 @@ Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
 =head1 CHANGE LOG
 
     $Log: Peek.pm,v $
-    Revision 0.03  2017/09/24 09:48:21 (UCT) Thanos
+    Revision 0.04  2017/09/26 09:38:21 (UCT) Thanos
 
 =cut
